grib2io.tables.section4_discipline209 API documentation

# grib2io.tables.section4_discipline209

View Source

      1table_4_2_209_2 = {
      2'0':['CG Average Lightning Density 1-min - NLDN','flashes/km^2/min','NLDN_CG_001min_AvgDensity'],
      3'1':['CG Average Lightning Density 5-min - NLDN','flashes/km^2/min','NLDN_CG_005min_AvgDensity'],
      4'2':['CG Average Lightning Density 15-min - NLDN','flashes/km^2/min','NLDN_CG_015min_AvgDensity'],
      5'3':['CG Average Lightning Density 30-min - NLDN','flashes/km^2/min','NLDN_CG_030min_AvgDensity'],
      6'5':['Lightning Probability 0-30 minutes - NLDN','%','LightningProbabilityNext30minGrid'],
      7'6':['Lightning Probability 0-30 minutes - NLDN','%','LightningProbabilityNext60minGrid'],
      8'7':['Rapid lightning increases and decreases ','non-dim','LightningJumpGrid'],
      9'8':['Rapid lightning increases and decreases over 5-minutes ','non-dim','LightningJumpGrid_Max_005min'],
     10}
     11
     12table_4_2_209_3 = {
     13'0':['Azimuth Shear 0-2km AGL','0.001/s','MergedAzShear0to2kmAGL'],
     14'1':['Azimuth Shear 3-6km AGL','0.001/s','MergedAzShear3to6kmAGL'],
     15'2':['Rotation Track 0-2km AGL 30-min','0.001/s','RotationTrack30min'],
     16'3':['Rotation Track 0-2km AGL 60-min','0.001/s','RotationTrack60min'],
     17'4':['Rotation Track 0-2km AGL 120-min','0.001/s','RotationTrack120min'],
     18'5':['Rotation Track 0-2km AGL 240-min','0.001/s','RotationTrack240min'],
     19'6':['Rotation Track 0-2km AGL 360-min','0.001/s','RotationTrack360min'],
     20'7':['Rotation Track 0-2km AGL 1440-min','0.001/s','RotationTrack1440min'],
     21'14':['Rotation Track 3-6km AGL 30-min','0.001/s','RotationTrackML30min'],
     22'15':['Rotation Track 3-6km AGL 60-min','0.001/s','RotationTrackML60min'],
     23'16':['Rotation Track 3-6km AGL 120-min','0.001/s','RotationTrackML120min'],
     24'17':['Rotation Track 3-6km AGL 240-min','0.001/s','RotationTrackML240min'],
     25'18':['Rotation Track 3-6km AGL 360-min','0.001/s','RotationTrackML360min'],
     26'19':['Rotation Track 3-6km AGL 1440-min','0.001/s','RotationTrackML1440min'],
     27'26':['Severe Hail Index','index','SHI'],
     28'27':['Prob of Severe Hail','%','POSH'],
     29'28':['Maximum Estimated Size of Hail (MESH)','mm','MESH'],
     30'29':['MESH Hail Swath 30-min','mm','MESHMax30min'],
     31'30':['MESH Hail Swath 60-min','mm','MESHMax60min'],
     32'31':['MESH Hail Swath 120-min','mm','MESHMax120min'],
     33'32':['MESH Hail Swath 240-min','mm','MESHMax240min'],
     34'33':['MESH Hail Swath 360-min','mm','MESHMax360min'],
     35'34':['MESH Hail Swath 1440-min','mm','MESHMax1440min'],
     36'37':['VIL Swath 120-min','kg/m^2','VIL_Max_120min'],
     37'40':['VIL Swath 1440-min','kg/m^2','VIL_Max_1440min'],
     38'41':['Vertically Integrated Liquid','kg/m^2','VIL'],
     39'42':['Vertically Integrated Liquid Density','g/m^3','VIL_Density'],
     40'43':['Vertically Integrated Ice','kg/m^2','VII'],
     41'44':['Echo Top - 18 dBZ','km MSL','EchoTop_18'],
     42'45':['Echo Top - 30 dBZ','km MSL','EchoTop_30'],
     43'46':['Echo Top - 50 dBZ','km MSL','EchoTop_50'],
     44'47':['Echo Top - 60 dBZ','km MSL','EchoTop_60'],
     45'48':['Thickness [50 dBZ top - (-20C)]','km','H50AboveM20C'],
     46'49':['Thickness [50 dBZ top - 0C]','km','H50Above0C'],
     47'50':['Thickness [60 dBZ top - (-20C)]','km','H60AboveM20C'],
     48'51':['Thickness [60 dBZ top - 0C]','km','H60Above0C'],
     49'52':['Isothermal Reflectivity at 0C','dBZ','Reflectivity_0C'],
     50'53':['Isothermal Reflectivity at -5C','dBZ','Reflectivity_-5C'],
     51'54':['Isothermal Reflectivity at -10C','dBZ','Reflectivity_-10C'],
     52'55':['Isothermal Reflectivity at -15C','dBZ','Reflectivity_-15C'],
     53'56':['Isothermal Reflectivity at -20C','dBZ','Reflectivity_-20C'],
     54'57':['ReflectivityAtLowestAltitude','dBZ','ReflectivityAtLowestAltitude'],
     55'57':['ReflectivityAtLowestAltitude resampled from 1 to 5km resolution','dBZ','ReflectivityAtLowestAltitude5km'],
     56'58':['Non Quality Controlled Reflectivity At Lowest Altitude','dBZ','MergedReflectivityAtLowestAltitude'],
     57}
     58
     59table_4_2_209_6 = {
     60'0':['Surface Precipitation Type (Convective, Stratiform, Tropical, Hail, Snow)','flag','PrecipFlag'],
     61'1':['Radar Precipitation Rate','mm/hr','PrecipRate'],
     62'2':['Radar precipitation accumulation 1-hour','mm','RadarOnly_QPE_01H'],
     63'3':['Radar precipitation accumulation 3-hour','mm','RadarOnly_QPE_03H'],
     64'4':['Radar precipitation accumulation 6-hour','mm','RadarOnly_QPE_06H'],
     65'5':['Radar precipitation accumulation 12-hour','mm','RadarOnly_QPE_12H'],
     66'6':['Radar precipitation accumulation 24-hour','mm','RadarOnly_QPE_24H'],
     67'7':['Radar precipitation accumulation 48-hour','mm','RadarOnly_QPE_48H'],
     68'8':['Radar precipitation accumulation 72-hour','mm','RadarOnly_QPE_72H'],
     69'30':['Multi-sensor accumulation 1-hour (1-hour latency)','mm','MultiSensor_QPE_01H_Pass1'],
     70'31':['Multi-sensor accumulation 3-hour (1-hour latency)','mm','MultiSensor_QPE_03H_Pass1'],
     71'32':['Multi-sensor accumulation 6-hour (1-hour latency)','mm','MultiSensor_QPE_06H_Pass1'],
     72'33':['Multi-sensor accumulation 12-hour (1-hour latency)','mm','MultiSensor_QPE_12H_Pass1'],
     73'34':['Multi-sensor accumulation 24-hour (1-hour latency)','mm','MultiSensor_QPE_24H_Pass1'],
     74'35':['Multi-sensor accumulation 48-hour (1-hour latency)','mm','MultiSensor_QPE_48H_Pass1'],
     75'36':['Multi-sensor accumulation 72-hour (1-hour latency)','mm','MultiSensor_QPE_72H_Pass1'],
     76'37':['Multi-sensor accumulation 1-hour (2-hour latency)','mm','MultiSensor_QPE_01H_Pass2'],
     77'38':['Multi-sensor accumulation 3-hour (2-hour latency)','mm','MultiSensor_QPE_03H_Pass2'],
     78'39':['Multi-sensor accumulation 6-hour (2-hour latency)','mm','MultiSensor_QPE_06H_Pass2'],
     79'40':['Multi-sensor accumulation 12-hour (2-hour latency)','mm','MultiSensor_QPE_12H_Pass2'],
     80'41':['Multi-sensor accumulation 24-hour (2-hour latency)','mm','MultiSensor_QPE_24H_Pass2'],
     81'42':['Multi-sensor accumulation 48-hour (2-hour latency)','mm','MultiSensor_QPE_48H_Pass2'],
     82'43':['Multi-sensor accumulation 72-hour (2-hour latency)','mm','MultiSensor_QPE_72H_Pass2'],
     83'44':['Method IDs for blended single and dual-pol derived precip rates ','flag','SyntheticPrecipRateID'],
     84'45':['Radar precipitation accumulation 15-minute','mm','RadarOnly_QPE_15M'],
     85'46':['Radar precipitation accumulation since 12Z','mm','RadarOnly_QPE_Since12Z'],
     86}
     87
     88table_4_2_209_7 = {
     89'0':['Model Surface temperature','C','Model_SurfaceTemp'],
     90'1':['Model Surface wet bulb temperature','C','Model_WetBulbTemp'],
     91'2':['Probability of warm rain','%','WarmRainProbability'],
     92'3':['Model Freezing Level Height','m MSL','Model_0degC_Height'],
     93'4':['Brightband Top Height','m AGL','BrightBandTopHeight'],
     94'5':['Brightband Bottom Height','m AGL','BrightBandBottomHeight'],
     95}
     96
     97table_4_2_209_8 = {
     98'0':['Radar Quality Index','non-dim','RadarQualityIndex'],
     99'1':['Gauge Influence Index for 1-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_01H_Pass1'],
    100'2':['Gauge Influence Index for 3-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_03H_Pass1'],
    101'3':['Gauge Influence Index for 6-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_06H_Pass1'],
    102'4':['Gauge Influence Index for 12-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_12H_Pass1'],
    103'5':['Gauge Influence Index for 24-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_24H_Pass1'],
    104'6':['Gauge Influence Index for 48-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_48H_Pass1'],
    105'7':['Gauge Influence Index for 72-hour QPE (1-hour latency)','non-dim','GaugeInflIndex_72H_Pass1'],
    106'8':['Seamless Hybrid Scan Reflectivity with VPR correction','dBZ','SeamlessHSR'],
    107'9':['Height of Seamless Hybrid Scan Reflectivity','km AGL','SeamlessHSRHeight'],
    108'10':['Radar 1-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_01H'],
    109'11':['Radar 3-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_03H'],
    110'12':['Radar 6-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_06H'],
    111'13':['Radar 12-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_12H'],
    112'14':['Radar 24-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_24H'],
    113'15':['Radar 48-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_48H'],
    114'16':['Radar 72-hour QPE Accumulation Quality','non-dim','RadarAccumulationQualityIndex_72H'],
    115'17':['Gauge Influence Index for 1-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_01H_Pass2'],
    116'18':['Gauge Influence Index for 3-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_03H_Pass2'],
    117'19':['Gauge Influence Index for 6-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_06H_Pass2'],
    118'20':['Gauge Influence Index for 12-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_12H_Pass2'],
    119'21':['Gauge Influence Index for 24-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_24H_Pass2'],
    120'22':['Gauge Influence Index for 48-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_48H_Pass2'],
    121'23':['Gauge Influence Index for 72-hour QPE (2-hour latency)','non-dim','GaugeInflIndex_72H_Pass2'],
    122}
    123
    124table_4_2_209_9 = {
    125'0':['3D Reflectivty Mosaic - 33 CAPPIS (500-19000m)','dBZ','MergedReflectivityQC'],
    126'3':['3D RhoHV Mosaic - 33 CAPPIS (500-19000m)','non-dim','MergedRhoHV'],
    127'4':['3D Zdr Mosaic - 33 CAPPIS (500-19000m)','dB','MergedZdr'],
    128}
    129
    130table_4_2_209_10 = {
    131'0':['Composite Reflectivity Mosaic (optimal method)','dBZ','MergedReflectivityQCComposite'],
    132'0':['Composite Reflectivity Mosaic (optimal method) resampled from 1 to 5km','dBZ','MergedReflectivityQCComposite5km'],
    133'1':['Height of Composite Reflectivity Mosaic (optimal method)','m MSL','HeightCompositeReflectivity'],
    134'2':['Low-Level Composite Reflectivity Mosaic (0-4km)','dBZ','LowLevelCompositeReflectivity'],
    135'3':['Height of Low-Level Composite Reflectivity Mosaic (0-4km)','m MSL','HeightLowLevelCompositeReflectivity'],
    136'4':['Layer Composite Reflectivity Mosaic 0-24kft (low altitude)','dBZ','LayerCompositeReflectivity_Low'],
    137'5':['Layer Composite Reflectivity Mosaic 24-60 kft (highest altitude)','dBZ','LayerCompositeReflectivity_High'],
    138'6':['Layer Composite Reflectivity Mosaic 33-60 kft (super high altitude)','dBZ','LayerCompositeReflectivity_Super'],
    139'7':['Composite Reflectivity Hourly Maximum','dBZ','CREF_1HR_MAX'],
    140'9':['Layer Composite Reflectivity Mosaic (2-4.5km) (for ANC)','dBZ','LayerCompositeReflectivity_ANC'],
    141'10':['Base Reflectivity Hourly Maximum','dBZ','BREF_1HR_MAX'],
    142}
    143
    144table_4_2_209_11 = {
    145'0':['Base Reflectivity Mosaic (optimal method)','dBZ','MergedBaseReflectivityQC'],
    146'1':['Raw Composite Reflectivity Mosaic (max ref)','dBZ','MergedReflectivityComposite'],
    147'2':['Composite Reflectivity Mosaic (max ref)','dBZ','MergedReflectivityQComposite'],
    148'3':['Raw Base Reflectivity Mosaic (optimal method)','dBZ','MergedBaseReflectivity'],
    149}
    150
    151table_4_2_209_12 = {
    152'0':['FLASH QPE-CREST Unit Streamflow','m^3/s/km^2','FLASH_CREST_MAXUNITSTREAMFLOW'],
    153'1':['FLASH QPE-CREST Streamflow','m^3/s','FLASH_CREST_MAXSTREAMFLOW'],
    154'2':['FLASH QPE-CREST Soil Saturation','%','FLASH_CREST_MAXSOILSAT'],
    155'4':['FLASH QPE-SAC Unit Streamflow','m^3/s/km^2','FLASH_SAC_MAXUNITSTREAMFLOW'],
    156'5':['FLASH QPE-SAC Streamflow','m^3/s','FLASH_SAC_MAXSTREAMFLOW'],
    157'6':['FLASH QPE-SAC Soil Saturation','%','FLASH_SAC_MAXSOILSAT'],
    158'14':['FLASH QPE Average Recurrence Interval 30-min','years','FLASH_QPE_ARI30M'],
    159'15':['FLASH QPE Average Recurrence Interval 01H','years','FLASH_QPE_ARI01H'],
    160'16':['FLASH QPE Average Recurrence Interval 03H','years','FLASH_QPE_ARI03H'],
    161'17':['FLASH QPE Average Recurrence Interval 06H','years','FLASH_QPE_ARI06H'],
    162'18':['FLASH QPE Average Recurrence Interval 12H','years','FLASH_QPE_ARI12H'],
    163'19':['FLASH QPE Average Recurrence Interval 24H','years','FLASH_QPE_ARI24H'],
    164'20':['FLASH QPE Average Recurrence Interval Maximum','years','FLASH_QPE_ARIMAX'],
    165'26':['FLASH QPE-to-FFG Ratio 01H','non-dim','FLASH_QPE_FFG01H'],
    166'27':['FLASH QPE-to-FFG Ratio 03H','non-dim','FLASH_QPE_FFG03H'],
    167'28':['FLASH QPE-to-FFG Ratio 06H','non-dim','FLASH_QPE_FFG06H'],
    168'29':['FLASH QPE-to-FFG Ratio Maximum','non-dim','FLASH_QPE_FFGMAX'],
    169'39':['FLASH QPE-Hydrophobic Unit Streamflow','m^3/s/km^2','FLASH_HP_MAXUNITSTREAMFLOW'],
    170'40':['FLASH QPE-Hydrophobic Streamflow','m^3/s','FLASH_HP_MAXSTREAMFLOW'],
    171}
    172
    173table_4_2_209_13 = {
    174'0':['Likelihood of convection over the next 01H','non-dim','ANC_ConvectiveLikelihood'],
    175'1':['01H reflectivity forecast','dBZ','ANC_FinalForecast'],
    176}
    177
    178table_4_2_209_14 = {
    179'0':['Level III High Resolution Enhanced Echo Top mosaic','kft','LVL3_HREET'],
    180'1':['Level III High Resouion VIL mosaic','kg/m^2','LVL3_HighResVIL'],
    181}

table_4_2_209_2 = {'0': ['CG Average Lightning Density 1-min - NLDN', 'flashes/km^2/min', 'NLDN_CG_001min_AvgDensity'], '1': ['CG Average Lightning Density 5-min - NLDN', 'flashes/km^2/min', 'NLDN_CG_005min_AvgDensity'], '2': ['CG Average Lightning Density 15-min - NLDN', 'flashes/km^2/min', 'NLDN_CG_015min_AvgDensity'], '3': ['CG Average Lightning Density 30-min - NLDN', 'flashes/km^2/min', 'NLDN_CG_030min_AvgDensity'], '5': ['Lightning Probability 0-30 minutes - NLDN', '%', 'LightningProbabilityNext30minGrid'], '6': ['Lightning Probability 0-30 minutes - NLDN', '%', 'LightningProbabilityNext60minGrid'], '7': ['Rapid lightning increases and decreases ', 'non-dim', 'LightningJumpGrid'], '8': ['Rapid lightning increases and decreases over 5-minutes ', 'non-dim', 'LightningJumpGrid_Max_005min']}
table_4_2_209_3 = {'0': ['Azimuth Shear 0-2km AGL', '0.001/s', 'MergedAzShear0to2kmAGL'], '1': ['Azimuth Shear 3-6km AGL', '0.001/s', 'MergedAzShear3to6kmAGL'], '2': ['Rotation Track 0-2km AGL 30-min', '0.001/s', 'RotationTrack30min'], '3': ['Rotation Track 0-2km AGL 60-min', '0.001/s', 'RotationTrack60min'], '4': ['Rotation Track 0-2km AGL 120-min', '0.001/s', 'RotationTrack120min'], '5': ['Rotation Track 0-2km AGL 240-min', '0.001/s', 'RotationTrack240min'], '6': ['Rotation Track 0-2km AGL 360-min', '0.001/s', 'RotationTrack360min'], '7': ['Rotation Track 0-2km AGL 1440-min', '0.001/s', 'RotationTrack1440min'], '14': ['Rotation Track 3-6km AGL 30-min', '0.001/s', 'RotationTrackML30min'], '15': ['Rotation Track 3-6km AGL 60-min', '0.001/s', 'RotationTrackML60min'], '16': ['Rotation Track 3-6km AGL 120-min', '0.001/s', 'RotationTrackML120min'], '17': ['Rotation Track 3-6km AGL 240-min', '0.001/s', 'RotationTrackML240min'], '18': ['Rotation Track 3-6km AGL 360-min', '0.001/s', 'RotationTrackML360min'], '19': ['Rotation Track 3-6km AGL 1440-min', '0.001/s', 'RotationTrackML1440min'], '26': ['Severe Hail Index', 'index', 'SHI'], '27': ['Prob of Severe Hail', '%', 'POSH'], '28': ['Maximum Estimated Size of Hail (MESH)', 'mm', 'MESH'], '29': ['MESH Hail Swath 30-min', 'mm', 'MESHMax30min'], '30': ['MESH Hail Swath 60-min', 'mm', 'MESHMax60min'], '31': ['MESH Hail Swath 120-min', 'mm', 'MESHMax120min'], '32': ['MESH Hail Swath 240-min', 'mm', 'MESHMax240min'], '33': ['MESH Hail Swath 360-min', 'mm', 'MESHMax360min'], '34': ['MESH Hail Swath 1440-min', 'mm', 'MESHMax1440min'], '37': ['VIL Swath 120-min', 'kg/m^2', 'VIL_Max_120min'], '40': ['VIL Swath 1440-min', 'kg/m^2', 'VIL_Max_1440min'], '41': ['Vertically Integrated Liquid', 'kg/m^2', 'VIL'], '42': ['Vertically Integrated Liquid Density', 'g/m^3', 'VIL_Density'], '43': ['Vertically Integrated Ice', 'kg/m^2', 'VII'], '44': ['Echo Top - 18 dBZ', 'km MSL', 'EchoTop_18'], '45': ['Echo Top - 30 dBZ', 'km MSL', 'EchoTop_30'], '46': ['Echo Top - 50 dBZ', 'km MSL', 'EchoTop_50'], '47': ['Echo Top - 60 dBZ', 'km MSL', 'EchoTop_60'], '48': ['Thickness [50 dBZ top - (-20C)]', 'km', 'H50AboveM20C'], '49': ['Thickness [50 dBZ top - 0C]', 'km', 'H50Above0C'], '50': ['Thickness [60 dBZ top - (-20C)]', 'km', 'H60AboveM20C'], '51': ['Thickness [60 dBZ top - 0C]', 'km', 'H60Above0C'], '52': ['Isothermal Reflectivity at 0C', 'dBZ', 'Reflectivity_0C'], '53': ['Isothermal Reflectivity at -5C', 'dBZ', 'Reflectivity_-5C'], '54': ['Isothermal Reflectivity at -10C', 'dBZ', 'Reflectivity_-10C'], '55': ['Isothermal Reflectivity at -15C', 'dBZ', 'Reflectivity_-15C'], '56': ['Isothermal Reflectivity at -20C', 'dBZ', 'Reflectivity_-20C'], '57': ['ReflectivityAtLowestAltitude resampled from 1 to 5km resolution', 'dBZ', 'ReflectivityAtLowestAltitude5km'], '58': ['Non Quality Controlled Reflectivity At Lowest Altitude', 'dBZ', 'MergedReflectivityAtLowestAltitude']}
table_4_2_209_6 = {'0': ['Surface Precipitation Type (Convective, Stratiform, Tropical, Hail, Snow)', 'flag', 'PrecipFlag'], '1': ['Radar Precipitation Rate', 'mm/hr', 'PrecipRate'], '2': ['Radar precipitation accumulation 1-hour', 'mm', 'RadarOnly_QPE_01H'], '3': ['Radar precipitation accumulation 3-hour', 'mm', 'RadarOnly_QPE_03H'], '4': ['Radar precipitation accumulation 6-hour', 'mm', 'RadarOnly_QPE_06H'], '5': ['Radar precipitation accumulation 12-hour', 'mm', 'RadarOnly_QPE_12H'], '6': ['Radar precipitation accumulation 24-hour', 'mm', 'RadarOnly_QPE_24H'], '7': ['Radar precipitation accumulation 48-hour', 'mm', 'RadarOnly_QPE_48H'], '8': ['Radar precipitation accumulation 72-hour', 'mm', 'RadarOnly_QPE_72H'], '30': ['Multi-sensor accumulation 1-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_01H_Pass1'], '31': ['Multi-sensor accumulation 3-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_03H_Pass1'], '32': ['Multi-sensor accumulation 6-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_06H_Pass1'], '33': ['Multi-sensor accumulation 12-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_12H_Pass1'], '34': ['Multi-sensor accumulation 24-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_24H_Pass1'], '35': ['Multi-sensor accumulation 48-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_48H_Pass1'], '36': ['Multi-sensor accumulation 72-hour (1-hour latency)', 'mm', 'MultiSensor_QPE_72H_Pass1'], '37': ['Multi-sensor accumulation 1-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_01H_Pass2'], '38': ['Multi-sensor accumulation 3-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_03H_Pass2'], '39': ['Multi-sensor accumulation 6-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_06H_Pass2'], '40': ['Multi-sensor accumulation 12-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_12H_Pass2'], '41': ['Multi-sensor accumulation 24-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_24H_Pass2'], '42': ['Multi-sensor accumulation 48-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_48H_Pass2'], '43': ['Multi-sensor accumulation 72-hour (2-hour latency)', 'mm', 'MultiSensor_QPE_72H_Pass2'], '44': ['Method IDs for blended single and dual-pol derived precip rates ', 'flag', 'SyntheticPrecipRateID'], '45': ['Radar precipitation accumulation 15-minute', 'mm', 'RadarOnly_QPE_15M'], '46': ['Radar precipitation accumulation since 12Z', 'mm', 'RadarOnly_QPE_Since12Z']}
table_4_2_209_7 = {'0': ['Model Surface temperature', 'C', 'Model_SurfaceTemp'], '1': ['Model Surface wet bulb temperature', 'C', 'Model_WetBulbTemp'], '2': ['Probability of warm rain', '%', 'WarmRainProbability'], '3': ['Model Freezing Level Height', 'm MSL', 'Model_0degC_Height'], '4': ['Brightband Top Height', 'm AGL', 'BrightBandTopHeight'], '5': ['Brightband Bottom Height', 'm AGL', 'BrightBandBottomHeight']}
table_4_2_209_8 = {'0': ['Radar Quality Index', 'non-dim', 'RadarQualityIndex'], '1': ['Gauge Influence Index for 1-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_01H_Pass1'], '2': ['Gauge Influence Index for 3-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_03H_Pass1'], '3': ['Gauge Influence Index for 6-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_06H_Pass1'], '4': ['Gauge Influence Index for 12-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_12H_Pass1'], '5': ['Gauge Influence Index for 24-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_24H_Pass1'], '6': ['Gauge Influence Index for 48-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_48H_Pass1'], '7': ['Gauge Influence Index for 72-hour QPE (1-hour latency)', 'non-dim', 'GaugeInflIndex_72H_Pass1'], '8': ['Seamless Hybrid Scan Reflectivity with VPR correction', 'dBZ', 'SeamlessHSR'], '9': ['Height of Seamless Hybrid Scan Reflectivity', 'km AGL', 'SeamlessHSRHeight'], '10': ['Radar 1-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_01H'], '11': ['Radar 3-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_03H'], '12': ['Radar 6-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_06H'], '13': ['Radar 12-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_12H'], '14': ['Radar 24-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_24H'], '15': ['Radar 48-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_48H'], '16': ['Radar 72-hour QPE Accumulation Quality', 'non-dim', 'RadarAccumulationQualityIndex_72H'], '17': ['Gauge Influence Index for 1-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_01H_Pass2'], '18': ['Gauge Influence Index for 3-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_03H_Pass2'], '19': ['Gauge Influence Index for 6-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_06H_Pass2'], '20': ['Gauge Influence Index for 12-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_12H_Pass2'], '21': ['Gauge Influence Index for 24-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_24H_Pass2'], '22': ['Gauge Influence Index for 48-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_48H_Pass2'], '23': ['Gauge Influence Index for 72-hour QPE (2-hour latency)', 'non-dim', 'GaugeInflIndex_72H_Pass2']}
table_4_2_209_9 = {'0': ['3D Reflectivty Mosaic - 33 CAPPIS (500-19000m)', 'dBZ', 'MergedReflectivityQC'], '3': ['3D RhoHV Mosaic - 33 CAPPIS (500-19000m)', 'non-dim', 'MergedRhoHV'], '4': ['3D Zdr Mosaic - 33 CAPPIS (500-19000m)', 'dB', 'MergedZdr']}
table_4_2_209_10 = {'0': ['Composite Reflectivity Mosaic (optimal method) resampled from 1 to 5km', 'dBZ', 'MergedReflectivityQCComposite5km'], '1': ['Height of Composite Reflectivity Mosaic (optimal method)', 'm MSL', 'HeightCompositeReflectivity'], '2': ['Low-Level Composite Reflectivity Mosaic (0-4km)', 'dBZ', 'LowLevelCompositeReflectivity'], '3': ['Height of Low-Level Composite Reflectivity Mosaic (0-4km)', 'm MSL', 'HeightLowLevelCompositeReflectivity'], '4': ['Layer Composite Reflectivity Mosaic 0-24kft (low altitude)', 'dBZ', 'LayerCompositeReflectivity_Low'], '5': ['Layer Composite Reflectivity Mosaic 24-60 kft (highest altitude)', 'dBZ', 'LayerCompositeReflectivity_High'], '6': ['Layer Composite Reflectivity Mosaic 33-60 kft (super high altitude)', 'dBZ', 'LayerCompositeReflectivity_Super'], '7': ['Composite Reflectivity Hourly Maximum', 'dBZ', 'CREF_1HR_MAX'], '9': ['Layer Composite Reflectivity Mosaic (2-4.5km) (for ANC)', 'dBZ', 'LayerCompositeReflectivity_ANC'], '10': ['Base Reflectivity Hourly Maximum', 'dBZ', 'BREF_1HR_MAX']}
table_4_2_209_11 = {'0': ['Base Reflectivity Mosaic (optimal method)', 'dBZ', 'MergedBaseReflectivityQC'], '1': ['Raw Composite Reflectivity Mosaic (max ref)', 'dBZ', 'MergedReflectivityComposite'], '2': ['Composite Reflectivity Mosaic (max ref)', 'dBZ', 'MergedReflectivityQComposite'], '3': ['Raw Base Reflectivity Mosaic (optimal method)', 'dBZ', 'MergedBaseReflectivity']}
table_4_2_209_12 = {'0': ['FLASH QPE-CREST Unit Streamflow', 'm^3/s/km^2', 'FLASH_CREST_MAXUNITSTREAMFLOW'], '1': ['FLASH QPE-CREST Streamflow', 'm^3/s', 'FLASH_CREST_MAXSTREAMFLOW'], '2': ['FLASH QPE-CREST Soil Saturation', '%', 'FLASH_CREST_MAXSOILSAT'], '4': ['FLASH QPE-SAC Unit Streamflow', 'm^3/s/km^2', 'FLASH_SAC_MAXUNITSTREAMFLOW'], '5': ['FLASH QPE-SAC Streamflow', 'm^3/s', 'FLASH_SAC_MAXSTREAMFLOW'], '6': ['FLASH QPE-SAC Soil Saturation', '%', 'FLASH_SAC_MAXSOILSAT'], '14': ['FLASH QPE Average Recurrence Interval 30-min', 'years', 'FLASH_QPE_ARI30M'], '15': ['FLASH QPE Average Recurrence Interval 01H', 'years', 'FLASH_QPE_ARI01H'], '16': ['FLASH QPE Average Recurrence Interval 03H', 'years', 'FLASH_QPE_ARI03H'], '17': ['FLASH QPE Average Recurrence Interval 06H', 'years', 'FLASH_QPE_ARI06H'], '18': ['FLASH QPE Average Recurrence Interval 12H', 'years', 'FLASH_QPE_ARI12H'], '19': ['FLASH QPE Average Recurrence Interval 24H', 'years', 'FLASH_QPE_ARI24H'], '20': ['FLASH QPE Average Recurrence Interval Maximum', 'years', 'FLASH_QPE_ARIMAX'], '26': ['FLASH QPE-to-FFG Ratio 01H', 'non-dim', 'FLASH_QPE_FFG01H'], '27': ['FLASH QPE-to-FFG Ratio 03H', 'non-dim', 'FLASH_QPE_FFG03H'], '28': ['FLASH QPE-to-FFG Ratio 06H', 'non-dim', 'FLASH_QPE_FFG06H'], '29': ['FLASH QPE-to-FFG Ratio Maximum', 'non-dim', 'FLASH_QPE_FFGMAX'], '39': ['FLASH QPE-Hydrophobic Unit Streamflow', 'm^3/s/km^2', 'FLASH_HP_MAXUNITSTREAMFLOW'], '40': ['FLASH QPE-Hydrophobic Streamflow', 'm^3/s', 'FLASH_HP_MAXSTREAMFLOW']}
table_4_2_209_13 = {'0': ['Likelihood of convection over the next 01H', 'non-dim', 'ANC_ConvectiveLikelihood'], '1': ['01H reflectivity forecast', 'dBZ', 'ANC_FinalForecast']}
table_4_2_209_14 = {'0': ['Level III High Resolution Enhanced Echo Top mosaic', 'kft', 'LVL3_HREET'], '1': ['Level III High Resouion VIL mosaic', 'kg/m^2', 'LVL3_HighResVIL']}